ZLMDB
=====

.. image:: https://img.shields.io/pypi/v/zlmdb.svg
    :target: https://pypi.python.org/pypi/zlmdb
    :alt: PyPI

.. image:: https://readthedocs.org/projects/zlmdb/badge/?version=latest
    :target: https://zlmdb.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation

.. image:: https://img.shields.io/travis/crossbario/zlmdb.svg
    :target: https://travis-ci.org/crossbario/zlmdb
    :alt: TravisCI

.. image:: https://codecov.io/gh/crossbario/zlmdb/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/crossbario/zlmdb
    :alt: Coverage

Object-relational in-memory database layer based on LMDB:

* High-performance (see below)
* Supports multiple serializers (JSON, CBOR, Pickle, Flatbuffers)
* Supports export/import from/to Apache Arrow
* Support native Numpy arrays and Pandas data frames
* Automatic indexes
* Free software (MIT license)
